

locals {
  # this is a hack to allow disabling everying. In tf 0.13 (in beta at the
  # time of writing) count can be applied to the module inclusion phase so this
  # won't be needed.

  count = var.email_address == "" ? 0 : 1
}

resource "google_monitoring_uptime_check_config" "https" {
  count        = local.count
  display_name = "https-uptime-check"

  timeout = var.uptime_timeout
  period  = var.uptime_period

  project = var.project

  http_check {
    path         = var.polling_path
    port         = "443"
    use_ssl      = true
    validate_ssl = true
  }

  monitored_resource {
    type = "uptime_url"
    labels = {
      project_id = var.project
      host       = var.monitored_domain
    }
  }

  # workaround - see https://github.com/terraform-providers/terraform-provider-google/issues/3133
  lifecycle {
    create_before_destroy = true
  }
}

resource "google_monitoring_notification_channel" "notification_email" {
  count        = local.count
  project      = var.project
  display_name = "Notifications Email"
  type         = "email"
  labels = {
    email_address = var.email_address
  }
}

resource "google_monitoring_alert_policy" "uptime_alert" {
  enabled               = var.enabled
  count                 = local.count
  project               = var.project
  display_name          = "HTTP uptime alert"
  notification_channels = [google_monitoring_notification_channel.notification_email[count.index].id]

  combiner = "OR"
  conditions {
    display_name = "http check failing for ${var.monitored_domain}${var.polling_path}"

    condition_threshold {
      filter          = <<-EOT
        metric.type="monitoring.googleapis.com/uptime_check/check_passed" AND
        metric.label.check_id="${google_monitoring_uptime_check_config.https[count.index].uptime_check_id}" AND 
        resource.type="uptime_url"
      EOT
      duration        = "60s"
      comparison      = "COMPARISON_GT"
      threshold_value = "1"
      trigger { count = "1" }
    }

  }
}
